@@ -22,7 +22,7 @@ except ImportError:
     sys.exit(1)
 
 
-class PyChess(object):
+class PyChess:
     def __init__(self):
         self.sd = MAXPLY
         self.skipPruneChance = 0
@@ -96,7 +96,7 @@ class PyChess(object):
             lsearch.skipPruneChance = self.skipPruneChance
             lsearch.searching = True
 
-            timed = (self.basetime > 0 or self.increment > 0)
+            timed = (self.basetime > 0 or self.increment > 0 or self.searchtime > 0)
 
             if self.searchtime > 0:
                 usetime = self.searchtime
