@@ -27,7 +27,7 @@ benchmarkPositions = [
 ]
 
 
-def benchmark():
+def benchmark(maxdepth=6):
     """ Times a search of a static list of positions. """
 
     suite_time = time()
@@ -41,14 +41,14 @@ def benchmark():
         board.applyFen(fen)
         pos_start_time = time()
         pos_start_nodes = lsearch.nodes
-        for depth in range(1, 6):
+        for depth in range(1, maxdepth):
             mvs, scr = lsearch.alphaBeta(board, depth)
             pos_time = time() - pos_start_time
             pos_nodes = lsearch.nodes - pos_start_nodes
             pv = " ".join(listToSan(board, mvs))
             time_cs = int(100 * pos_time)
             print(depth, scr, time_cs, pos_nodes, pv)
-        print("Searched position", i, "at", int(pos_nodes / pos_time), "n/s")
+        print("Searched position", i, "at", int(pos_nodes / pos_time) if pos_time > 0 else pos_nodes, "n/s")
     suite_time = time() - suite_time
     suite_nodes = lsearch.nodes - suite_nodes
     print("Total:", suite_nodes, "nodes in", suite_time, "s: ", suite_nodes /
