@@ -15,5 +15,5 @@ class ICCListAndVarManager(ListAndVarManager):
 
     def autoFlagNotify(self, *args):
         self.connection.client.run_command(
-            "set autoflag %s" % int(conf.get('autoCallFlag', False)))
-        # print 'notify flag', conf.get('autoCallFlag',False)
+            "set autoflag %s" % int(conf.get('autoCallFlag')))
+        # print 'notify flag', conf.get('autoCallFlag')
