@@ -3,7 +3,7 @@ import ast
 
 from gi.repository import GLib, Gdk, Gtk, GObject
 
-from pychess.Utils.const import chr2Sign, WHITE, BLACK
+from pychess.Utils.const import chr2Sign, WHITE, BLACK, NORMALCHESS
 from pychess.Utils.Piece import Piece
 from pychess.Utils.SetupModel import SetupModel, SetupPlayer
 from pychess.System import uistuff
@@ -98,7 +98,7 @@ class FilterPanel(Gtk.TreeView):
         self.set_headers_visible(True)
         self.set_grid_lines(Gtk.TreeViewGridLines.HORIZONTAL)
 
-        column = Gtk.TreeViewColumn("filter", Gtk.CellRendererText(), text=0)
+        column = Gtk.TreeViewColumn(_("Filter"), Gtk.CellRendererText(), text=0)
         column.set_min_width(80)
         self.append_column(column)
 
@@ -132,7 +132,7 @@ class FilterPanel(Gtk.TreeView):
         addSeqButton = Gtk.ToolButton()
         addSeqButton.set_label(_("Seq"))
         addSeqButton.set_is_important(True)
-        addSeqButton.set_tooltip_text(_("Create new squence where listed conditions may be satisfied at different times in a game"))
+        addSeqButton.set_tooltip_text(_("Create new sequence where listed conditions may be satisfied at different times in a game"))
         addSeqButton.connect("clicked", self.on_add_sequence_clicked)
         toolbar.insert(addSeqButton, -1)
 
@@ -644,4 +644,4 @@ class FilterPanel(Gtk.TreeView):
         GLib.idle_add(self.fen_changed)
 
     def get_fen(self):
-        return self.setupmodel.boards[-1].as_fen()
+        return self.setupmodel.boards[-1].as_fen(NORMALCHESS)
