@@ -6,9 +6,10 @@ from gi.repository import Gdk, Gtk, GObject, Pango, PangoCairo
 from pychess.compat import create_task
 from pychess.System import conf, uistuff
 from pychess.Utils import prettyPrintScore
-from pychess.Utils.const import HINT, OPENING, SPY, BLACK, NULL_MOVE, ENDGAME, DRAW, WHITEWON, WHITE, NORMALCHESS
+from pychess.Utils.const import HINT, OPENING, SPY, BLACK, ENDGAME, DRAW, WHITEWON, WHITE, NORMALCHESS
 from pychess.Utils.book import getOpenings
 from pychess.Utils.eco import get_eco
+from pychess.Utils.IconLoader import get_pixbuf
 from pychess.Utils.logic import legalMoveCount
 from pychess.Utils.Move import Move, toSAN, toFAN, listToMoves
 from pychess.Utils.lutils.lmovegen import newMove
@@ -128,7 +129,7 @@ class OpeningAdvisor(Advisor):
                 eco = ""
 #                self.opening_names.append("")
             else:
-                eco = "%s - %s%s%s" % (opening[0], opening[1], ', ' if opening[2] != '' else '', opening[2])
+                eco = "%s %s%s%s" % (opening[0], opening[1], ', ' if opening[2] != '' else '', opening[2])
 #                self.opening_names.append("%s %s" % (opening[1], opening[2]))
                 if opening[3] == int(False):
                     eco = '(...) %s' % eco.strip()
@@ -324,7 +325,7 @@ class EngineAdvisor(Advisor):
                 # we need to chage it to get the board in gamemodel variations board list later
                 board.setColor(1 - board.color)
                 king = board.kings[board.color]
-                null_move = Move(newMove(king, king, NULL_MOVE))
+                null_move = Move(newMove(king, king))
                 model.add_variation(self.engine.board, [null_move] + moves)
 
     def child_tooltip(self, i):
@@ -359,14 +360,13 @@ class EndgameAdvisor(Advisor):
     class StopNow(Exception):
         pass
 
-    @asyncio.coroutine
-    def start(self):
+    async def start(self):
         while True:
-            v = yield from self.queue.get()
+            v = await self.queue.get()
             if isinstance(v, Exception) and v == self.StopNow:
                 break
             elif v == self.board.board:
-                ret = yield from self.egtb.scoreAllMoves(v)
+                ret = await self.egtb.scoreAllMoves(v)
                 self.on_scored(v, ret)
             self.queue.task_done()
 
@@ -510,6 +510,9 @@ class Sidepanel:
         self.toggleRenderer.set_property("stock-id", "gtk-add")
         c4 = Gtk.TreeViewColumn("StartStop", self.toggleRenderer)
 
+        self.play_image = get_pixbuf("glade/play.png")
+        self.pause_image = get_pixbuf("glade/pause.png")
+
         def cb_visible(column, cell, store, iter, data):
             if not store[iter][6]:
                 cell.set_property('visible', False)
@@ -517,9 +520,9 @@ class Sidepanel:
                 cell.set_property('visible', True)
 
             if store[iter][5]:
-                cell.set_property("stock-id", "gtk-media-play")
+                cell.set_property("pixbuf", self.play_image)
             else:
-                cell.set_property("stock-id", "gtk-media-pause")
+                cell.set_property("pixbuf", self.pause_image)
 
         c4.set_cell_data_func(self.toggleRenderer, cb_visible)
 
